<?php

/**
 * Kopano settings controller.
 *
 * @category   apps
 * @package    kopano
 * @subpackage controllers
 * @author     ClearFoundation <developer@clearfoundation.com>
 * @copyright  2016 ClearFoundation
 * @license    http://www.gnu.org/copyleft/gpl.html GNU General Public License version 3 or later
 * @link       http://www.clearfoundation.com/docs/developer/apps/kopano/
 */

///////////////////////////////////////////////////////////////////////////////
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

/**
 * Kopano settings controller.
 *
 * @category   apps
 * @package    kopano
 * @subpackage controllers
 * @author     ClearFoundation <developer@clearfoundation.com>
 * @copyright  2016 ClearFoundation
 * @license    http://www.gnu.org/copyleft/gpl.html GNU General Public License version 3 or later
 * @link       http://www.clearfoundation.com/docs/developer/apps/kopano/
 */

class Kopano_Settings extends ClearOS_Controller
{
    protected $basename = NULL;

    /**
     * Kopano settings constructor.
     * 
     * @param string $basename app basename
     */

    function __construct($basename)
    {
        $this->basename = $basename;
    }

    /**
     * Kopano settings default controller.
     *
     * @return view
     */

    function index()
    {
        $this->view();
    }

    /**
     * Edit view.
     *
     * @return view
     */

    function edit()
    {
        $this->_view_edit('edit');
    }

    /**
     * View view.
     *
     * @return view
     */

    function view()
    {
        $this->_view_edit('view');
    }

    /**
     * Common view/edit form.
     *
     * @param string $form_mode form mode
     *
     * @return view
     */

    function _view_edit($form_mode)
    {
        // Load dependencies
        //------------------

        $this->lang->load('base');
        $this->lang->load('kopano');
        $this->load->library('kopano/Kopano_Gateway');
        $this->load->library('kopano/Kopano_iCal');
        $this->load->library('kopano/Kopano_Spooler');

        // Bail if account status is unhappy/unitialized
        //----------------------------------------------

        $this->load->module('accounts/status');

        if ($this->status->unhappy())
            return;

        // Set validation rules
        //---------------------
         
        $this->form_validation->set_policy('pop3', 'kopano/Kopano_Gateway', 'validate_port', FALSE);
        $this->form_validation->set_policy('pop3s', 'kopano/Kopano_Gateway', 'validate_port', FALSE);
        $this->form_validation->set_policy('imap', 'kopano/Kopano_Gateway', 'validate_port', FALSE);
        $this->form_validation->set_policy('imaps', 'kopano/Kopano_Gateway', 'validate_port', FALSE);
        $this->form_validation->set_policy('ical', 'kopano/Kopano_iCal', 'validate_port', FALSE);
        $this->form_validation->set_policy('icals', 'kopano/Kopano_iCal', 'validate_port', FALSE);
        $this->form_validation->set_policy('sender', 'kopano/Kopano_Spooler', 'validate_state', TRUE);
        $form_ok = $this->form_validation->run();

        // Handle form submit
        //-------------------

        if (($this->input->post('submit') && $form_ok)) {
            try {
                $this->kopano_gateway->set_port('pop3', $this->input->post('pop3'));
                $this->kopano_gateway->set_port('pop3s', $this->input->post('pop3s'));
                $this->kopano_gateway->set_port('imap', $this->input->post('imap'));
                $this->kopano_gateway->set_port('imaps', $this->input->post('imaps'));

                $this->kopano_ical->set_port('ical', $this->input->post('ical'));
                $this->kopano_ical->set_port('icals', $this->input->post('icals'));

                // Reverse "strict sender policy" is a reverse boolean to "always send delegates"
                $policy = ($this->input->post('sender')) ? FALSE : TRUE;
                $this->kopano_spooler->set_always_send_delegates($policy);

                $this->kopano_gateway->reset(FALSE);
                $this->kopano_ical->reset(FALSE);
                $this->kopano_spooler->reset(FALSE);

                $this->page->set_status_updated();
                redirect('/' . $this->basename . '/settings');
            } catch (Exception $e) {
                $this->page->view_exception($e);
                return;
            }
        }

        // Load view data
        //---------------

        try {
            $data['form_mode'] = $form_mode;
            $data['basename'] = $this->basename;

            $data['pop3'] = $this->kopano_gateway->get_port('pop3');
            $data['pop3s'] = $this->kopano_gateway->get_port('pop3s');
            $data['imap'] = $this->kopano_gateway->get_port('imap');
            $data['imaps'] = $this->kopano_gateway->get_port('imaps');

            $data['ical'] = $this->kopano_ical->get_port('ical');
            $data['icals'] = $this->kopano_ical->get_port('icals');

            // Reverse "strict sender policy" is a reverse boolean to "always send delegates"
            $data['sender'] = ($this->kopano_spooler->get_always_send_delegates()) ? FALSE : TRUE;
        } catch (Exception $e) {
            $this->page->view_exception($e);
            return;
        }

        // Load views
        //-----------

        $this->page->view_form('kopano/settings', $data, lang('base_settings'));
    }
}
