<?php

/**
 * Kopano Server class.
 *
 * @category   apps
 * @package    kopano
 * @subpackage libraries
 * @author     ClearFoundation <developer@clearfoundation.com>
 * @copyright  2010-2011 Tim Burgess
 * @copyright  2011-2016 ClearFoundation
 * @license    http://www.gnu.org/copyleft/lgpl.html GNU Lesser General Public License version 3 or later
 * @link       http://www.clearfoundation.com/docs/developer/apps/kopano/
 */

///////////////////////////////////////////////////////////////////////////////
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
// N A M E S P A C E
///////////////////////////////////////////////////////////////////////////////

namespace clearos\apps\kopano;

///////////////////////////////////////////////////////////////////////////////
// B O O T S T R A P
///////////////////////////////////////////////////////////////////////////////

$bootstrap = getenv('CLEAROS_BOOTSTRAP') ? getenv('CLEAROS_BOOTSTRAP') : '/usr/clearos/framework/shared';
require_once $bootstrap . '/bootstrap.php';

///////////////////////////////////////////////////////////////////////////////
// T R A N S L A T I O N S
///////////////////////////////////////////////////////////////////////////////

clearos_load_language('kopano');

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

use \clearos\apps\base\Daemon as Daemon;
use \clearos\apps\base\File as File;

clearos_load_library('base/Daemon');
clearos_load_library('base/File');

///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

/**
 * Kopano Server class.
 *
 * @category   apps
 * @package    kopano
 * @subpackage libraries
 * @author     ClearFoundation <developer@clearfoundation.com>
 * @copyright  2010-2011 Tim Burgess
 * @copyright  2011-2016 ClearFoundation
 * @license    http://www.gnu.org/copyleft/lgpl.html GNU Lesser General Public License version 3 or later
 * @link       http://www.clearfoundation.com/docs/developer/apps/kopano/
 */

class Kopano_Server extends Daemon
{
    ///////////////////////////////////////////////////////////////////////////////
    // C O N S T A N T S
    ///////////////////////////////////////////////////////////////////////////////

    const FILE_KOPANO_SERVER = '/etc/kopano/server.cfg';

    ///////////////////////////////////////////////////////////////////////////////
    // M E T H O D S
    ///////////////////////////////////////////////////////////////////////////////

    /**
     * Kopano constructor.
     */

    function __construct()
    {
        clearos_profile(__METHOD__, __LINE__);

        parent::__construct('kopano-server');
    }

    /**
     * Returns MySQL configuration.
     *
     * @return array MySQL configuration
     * @throws Engine_EXception
     */

    public function get_mysql_config()
    {
        clearos_profile(__METHOD__, __LINE__);

        $file = new File(self::FILE_KOPANO_SERVER);

        $retval = $file->lookup_value("/^mysql_password\s+/i");
        $output['password'] = trim($retval, " = ");

        $retval2 = $file->lookup_value("/^mysql_host\s+/i");
        $output['host'] = trim($retval2, " = ");

        $retval3 = $file->lookup_value("/^mysql_port\s+/i");
        $output['port'] = trim($retval3, " = ");

        return $output;
    }

    /**
     * Sets MySQL config.
     *
     * @param string $password password  
     * @param string $host     host
     * @param string $port     port
     *
     * @return void
     * @throws Validation_Exception, Engine_Exception
     */

    public function set_mysql_config($password, $host, $port)
    {
        clearos_profile(__METHOD__, __LINE__);

        $file = new File(self::FILE_KOPANO_SERVER);

        $match = $file->replace_lines("/^mysql_password\s+/i", "mysql_password = $password\n");

        if (! $match)
            $file->add_lines_after("mysql_password = $password\n", "/^[^#]/");

        $match2 = $file->replace_lines("/^mysql_host\s+/i", "mysql_host = $host\n");

        if (! $match2)
            $file->add_lines_after("mysql_host = $host\n", "/^[^#]/");

        $match3 = $file->replace_lines("/^mysql_port\s+/i", "mysql_port = $port\n");

        if (! $match3)
            $file->add_lines_after("mysql_port = $port\n", "/^[^#]/");
    }
}
