<?php

/**
 * Kopano subscription engine class.
 *
 * @category   apps
 * @package    kopano
 * @subpackage libraries
 * @author     ClearFoundation <developer@clearfoundation.com>
 * @copyright  2016 ClearFoundation
 * @license    http://www.gnu.org/copyleft/lgpl.html GNU Lesser General Public License version 3 or later
 * @link       http://www.clearfoundation.com/docs/developer/apps/kopano/
 */

///////////////////////////////////////////////////////////////////////////////
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
// N A M E S P A C E
///////////////////////////////////////////////////////////////////////////////

namespace clearos\apps\kopano;

///////////////////////////////////////////////////////////////////////////////
// B O O T S T R A P
///////////////////////////////////////////////////////////////////////////////

$bootstrap = getenv('CLEAROS_BOOTSTRAP') ? getenv('CLEAROS_BOOTSTRAP') : '/usr/clearos/framework/shared';
require_once $bootstrap . '/bootstrap.php';

///////////////////////////////////////////////////////////////////////////////
// T R A N S L A T I O N S
///////////////////////////////////////////////////////////////////////////////

clearos_load_language('kopano');

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

use \clearos\apps\base\Shell as Shell;
use \clearos\apps\clearcenter\Subscription_Engine as Subscription_Engine;
use \clearos\apps\marketplace\Marketplace as Marketplace;
use \clearos\apps\kopano\Kopano_Server as Kopano_Server;

clearos_load_library('base/Shell');
clearos_load_library('clearcenter/Subscription_Engine');
clearos_load_library('marketplace/Marketplace');
clearos_load_library('kopano/Kopano_Server');

///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

/**
 * Kopano subscription engine class.
 *
 * @category   apps
 * @package    kopano
 * @subpackage libraries
 * @author     ClearFoundation <developer@clearfoundation.com>
 * @copyright  2016 ClearFoundation
 * @license    http://www.gnu.org/copyleft/lgpl.html GNU Lesser General Public License version 3 or later
 * @link       http://www.clearfoundation.com/docs/developer/apps/kopano/
 */

class Kopano_Subscription_Engine extends Subscription_Engine
{
    ///////////////////////////////////////////////////////////////////////////////
    // C O N S T A N T S
    ///////////////////////////////////////////////////////////////////////////////

    const COMMAND_KOPANO_ADMIN = '/usr/sbin/kopano-admin';

    ///////////////////////////////////////////////////////////////////////////////
    // M E M B E R S
    ///////////////////////////////////////////////////////////////////////////////

    protected $app_name = NULL;
    protected $type = Subscription_Engine::TYPE_USER;

    ///////////////////////////////////////////////////////////////////////////////
    // M E T H O D S
    ///////////////////////////////////////////////////////////////////////////////

    /**
     * Kopano subscription engine constructor.
     */

    public function __construct($app_name)
    {
        clearos_profile(__METHOD__, __LINE__);

        $this->app_name = $app_name;
    }

    /**
     * Returns subscription information.
     *
     * @return array subscription information
     *
     * @throws Engine_Exception
     */

    public function get_info()
    {
        clearos_profile(__METHOD__, __LINE__);

        $info = array(
            'app_name' => $this->app_name,
            'type' => $this->type,
            'total' => 0,
            'used' => 0,
            'available' => 0,
        );

        $info['user_limit']['extension']['kopano'] = array('account_flag');

        $shell = new Shell();
        $options['env'] = 'LANG=en_US';

        $basename = NULL;
        if (clearos_library_installed('kopano_basic/Kopano_Basic_Subscription'))
            $basename = 'kopano_basic';
        else if (clearos_library_installed('kopano_professional/Kopano_Professional_Subscription'))
            $basename = 'kopano_professional';
        if ($basename != NULL) {
            try {
                $marketplace = new Marketplace();
                $app_info = json_decode($marketplace->get_app_details($basename));
                if (isset($app_info->details->license_info->evaluation) && $app_info->details->license_info->evaluation == TRUE) {
                    // Hardcode Alert...Kopano Evaluations limit to 25 users
                    $info['total'] = 25; 
                    $info['available'] = 25;
                    return $info;
                }
            } catch (Exception $e) {
                // Ignore
            }
        }

        // KLUDGE: user counts are only available if Kopano Server is running.
        // Return a large number in this case (ideally, the subscription
        // manager would handle errors)

        $kopano_server = new Kopano_Server();

        if (! $kopano_server->get_running_state()) {
            $info['available'] = 10000;
            return $info;
        }

        $shell->execute(self::COMMAND_KOPANO_ADMIN, '--user-count', TRUE, $options);

        $rows = $shell->get_output();

        foreach ($rows as $row) {
            if (preg_match('/^\s*Active\s+(\d+)\s+(\d+)\s+(\d+).*/', $row, $match)) {
                $info['total'] = (int) $match[1]; 
                $info['used'] = (int) $match[2]; 
                $info['available'] = (int) $match[3]; 
                break;
            }
        }

        return $info;
    }
}
