<?php

/**
 * Kopano Basic for ClearOS license controller.
 *
 * @category   apps
 * @package    kopano-basic
 * @subpackage controllers
 * @author     ClearCenter <developer@clearcenter.com>
 * @copyright  2016 ClearCenter
 * @license    http://www.clearcenter.com/app_license ClearCenter license
 * @link       http://www.clearcenter.com/support/documentation/clearos/kopano_basic/
 */

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

use \Exception as Exception;

///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

/**
 * Kopano Basic for ClearOS license controller.
 *
 * @category   apps
 * @package    kopano-basic
 * @subpackage controllers
 * @author     ClearCenter <developer@clearcenter.com>
 * @copyright  2016 ClearCenter
 * @license    http://www.clearcenter.com/app_license ClearCenter license
 * @link       http://www.clearcenter.com/support/documentation/clearos/kopano_basic/
 */

class Licenses extends ClearOS_Controller
{
    /**
     * DNS server summary view.
     *
     * @return view
     */

    function index()
    {
        // Load libraries
        //---------------

        $this->lang->load('kopano_basic');
        $this->load->library('kopano_basic/Kopano_Licensed');

        // Load view data
        //---------------

        try {
            $data['licenses'] = $this->kopano_licensed->get_licenses();
        } catch (Exception $e) {
            $this->page->view_exception($e);
            return;
        }
 
        // Load views
        //-----------

        $this->page->view_form('kopano_basic/summary', $data, lang('kopano_basic_licenses'));
    }

    /**
     * Add x entry view.
     *
     * @param string $file license file
     *
     * @return view
     */

    function add()
    {
        $this->_item('add');
    }

    /**
     * Delete entry view.
     *
     * @param string $file license file
     *
     * @return view
     */

    function delete($file)
    {
        $confirm_uri = '/app/kopano_basic/licenses/destroy/' . $file;
        $cancel_uri = '/app/kopano_basic/licenses';
        $items = array($file);

        $this->page->view_confirm_delete($confirm_uri, $cancel_uri, $items);
    }

    /**
     * Edit entry view.
     *
     * @param string $file license file
     *
     * @return view
     */

    function edit($file)
    {
        $this->_item('edit', $file);
    }

    /**
     * Destroy entry view.
     *
     * @param string $file license file
     *
     * @return view
     */

    function destroy($file)
    {
        // Load libraries
        //---------------

        $this->load->library('kopano_basic/Kopano_Licensed');

        // Handle delete
        //--------------

        try {
            $this->kopano_licensed->delete_license($file);
            $this->kopano_licensed->reset(TRUE);

            $this->page->set_status_deleted();
            redirect('/kopano_basic/licenses');
        } catch (Exception $e) {
            $this->page->view_exception($e);
            return;
        }
    }

    /**
     * Get stats
     *
     * @return JSON
     */

    function get_stats()
    {
        clearos_profile(__METHOD__, __LINE__);

        header('Cache-Control: no-cache, must-revalidate');
        header('Content-type: application/json');

        // Load libraries
        //---------------

        $this->load->library('kopano_basic/Kopano_Licensed');

        try {
            $stats = $this->kopano_licensed->get_cal_stats();
            echo json_encode(array('code' => 0, 'stats' => $stats));
        } catch (Exception $e) {
            echo json_encode(array('code' => 1, 'errmsg' => clearos_exception_message($e)));
        }
    }

    ///////////////////////////////////////////////////////////////////////////////
    // P R I V A T E
    ///////////////////////////////////////////////////////////////////////////////

    /**
     * Common add/edit form handler.
     *
     * @param string $form_type form type
     * @param string $file      license file
     *
     * @return view
     */

    function _item($form_type, $file = '')
    {
        // Load libraries
        //---------------

        $this->lang->load('kopano_basic');
        $this->load->library('kopano_basic/Kopano_Licensed');

        // Set validation rules
        //---------------------

        $this->form_validation->set_policy('serial', 'kopano_basic/Kopano_Licensed', 'validate_serial', TRUE);

        $form_ok = $this->form_validation->run();

        // Handle form submit
        //-------------------

        if ($this->input->post('submit') && ($form_ok === TRUE)) {

            try {
                if ($form_type === 'edit') 
                    $this->kopano_licensed->update_license($this->input->post('file'), $this->input->post('serial'));
                else
                    $this->kopano_licensed->add_license($this->input->post('serial'));

                $this->kopano_licensed->reset(TRUE);
                $this->page->set_status_updated();
                redirect('/kopano_basic/licenses');
            } catch (Exception $e) {
                $this->page->view_exception($e);
                return;
            }
        }

        // Load the view data 
        //------------------- 

        try {
            if ($form_type === 'edit') 
                $data['serial'] = $this->kopano_licensed->get_serial($file);
            else
                $data['serial'] = '';
        } catch (Exception $e) {
            $this->page->view_exception($e);
            return;
        }

        $data['form_type'] = $form_type;
        $data['file'] = $file;

        // Load the views
        //---------------

        $this->page->view_form('item', $data, lang('kopano_basic_licenses'));
    }
}
