<?php

/**
 * Kopano basic subscription class.
 *
 * @category   apps
 * @package    kopano
 * @subpackage libraries
 * @author     ClearCenter <developer@clearcenter.com>
 * @copyright  2016 ClearCenter
 * @license    http://www.gnu.org/copyleft/lgpl.html GNU Lesser General Public License version 3 or later
 * @link       http://www.clearfoundation.com/docs/developer/apps/kopano/
 */

///////////////////////////////////////////////////////////////////////////////
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
// N A M E S P A C E
///////////////////////////////////////////////////////////////////////////////

namespace clearos\apps\kopano_basic;

///////////////////////////////////////////////////////////////////////////////
// B O O T S T R A P
///////////////////////////////////////////////////////////////////////////////

$bootstrap = getenv('CLEAROS_BOOTSTRAP') ? getenv('CLEAROS_BOOTSTRAP') : '/usr/clearos/framework/shared';
require_once $bootstrap . '/bootstrap.php';

///////////////////////////////////////////////////////////////////////////////
// T R A N S L A T I O N S
///////////////////////////////////////////////////////////////////////////////

clearos_load_language('kopano_basic');

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

use \clearos\apps\base\File as File;
use \clearos\apps\clearcenter\Subscription_Engine as Subscription_Engine;
use \clearos\apps\kopano\Kopano_Subscription_Engine as Kopano_Subscription_Engine;
use \clearos\apps\kopano_basic\Kopano_Licensed as Kopano_Licensed;

clearos_load_library('base/File');
clearos_load_library('clearcenter/Subscription_Engine');
clearos_load_library('kopano/Kopano_Subscription_Engine');
clearos_load_library('kopano_basic/Kopano_Licensed');

///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

/**
 * Kopano basic subscription class.
 *
 * @category   apps
 * @package    kopano
 * @subpackage libraries
 * @author     ClearCenter <developer@clearcenter.com>
 * @copyright  2016 ClearCenter
 * @license    http://www.gnu.org/copyleft/lgpl.html GNU Lesser General Public License version 3 or later
 * @link       http://www.clearfoundation.com/docs/developer/apps/kopano/
 */

class Kopano_Basic_Subscription extends Kopano_Subscription_Engine
{

    ///////////////////////////////////////////////////////////////////////////////
    // C O N S T A N T S
    ///////////////////////////////////////////////////////////////////////////////

    ///////////////////////////////////////////////////////////////////////////////
    // M E T H O D S
    ///////////////////////////////////////////////////////////////////////////////

    /**
     * Kopano Basic subscription constructor.
     */

    public function __construct()
    {
        clearos_profile(__METHOD__, __LINE__);

        parent::__construct(lang('kopano_basic_app_name'));
    }

    /**
     * Returns subscription information.
     *
     * @return array subscription information
     *
     * @throws Engine_Exception
     */

    public function get_info()
    {
        clearos_profile(__METHOD__, __LINE__);

        $licensed = new Kopano_Licensed();
        $stats = $licensed->get_cal_stats();

        $info = array(
            'app_name' => lang('kopano_basic_app_name'),
            'type' => Subscription_Engine::TYPE_USER,
            'total' => $stats['total'],
            'used' => $stats['used'],
            'available' => $stats['available']
        );

        return $info;
    }
}
